API docs for “spamfighter.core.commands.partner.CommandParamMergerMeta”

# Class s.c.c.p.CommandParamMergerMeta(type):

Part of spamfighter.core.commands.partner View Source View In Hierarchy

Мета-тип, который собирает вместе сигнатуру команд по цепочке наследования классов.

Method | __init__ | Собираем вместе `commandSignature` от всех предков и от нашего класса.

def __init__(cls, name, bases, dict): (source)
Собираем вместе `commandSignature` от всех предков и от нашего класса.